ExecuteMsg

Enum ExecuteMsg 

pub enum ExecuteMsg<T> {
Show 19 variants SetNameMarketplace { address: String, }, AssociateAddress { name: String, address: Option<String>, }, UpdateImageNft { name: String, nft: Option<NFT>, }, AddTextRecord { name: String, record: TextRecord, }, RemoveTextRecord { name: String, record_name: String, }, UpdateTextRecord { name: String, record: TextRecord, }, VerifyTextRecord { name: String, record_name: String, result: bool, }, UpdateVerifier { verifier: Option<String>, }, TransferNft { recipient: String, token_id: String, }, SendNft { contract: String, token_id: String, msg: Binary, }, Approve { spender: String, token_id: String, expires: Option<Expiration>, }, Revoke { spender: String, token_id: String, }, ApproveAll { operator: String, expires: Option<Expiration>, }, RevokeAll { operator: String, }, Mint(MintMsg<T>), Burn { token_id: String, }, UpdateCollectionInfo { collection_info: UpdateCollectionInfoMsg<RoyaltyInfoResponse>, }, UpdateStartTradingTime(Option<Timestamp>), FreezeCollectionInfo {},
}

Variants



SetNameMarketplace

Set name marketplace contract address

Fields

address: String


AssociateAddress

Set an address for name reverse lookup and updates token_uri Can be an EOA or a contract address.

Fields

name: String
address: Option<String>


UpdateImageNft

Update image NFT

Fields

name: String


AddTextRecord

Add text record ex: twitter handle, discord name, etc

Fields

name: String
record: TextRecord


RemoveTextRecord

Remove text record ex: twitter handle, discord name, etc

Fields

name: String
record_name: String


UpdateTextRecord

Update text record ex: twitter handle, discord name, etc

Fields

name: String
record: TextRecord


VerifyTextRecord

Verify a text record as true or false (via oracle)

Fields

name: String
record_name: String
result: bool


UpdateVerifier

Update the reset the verification oracle

Fields

verifier: Option<String>


TransferNft

Transfer is a base message to move a token to another account without triggering actions

Fields

recipient: String
token_id: String


SendNft

Send is a base message to transfer a token to a contract and trigger an action on the receiving contract.

Fields

contract: String
token_id: String


Approve

Allows operator to transfer / send the token from the owner’s account. If expiration is set, then this allowance has a time/height limit

Fields

spender: String
token_id: String


Revoke

Remove previously granted Approval

Fields

spender: String
token_id: String


ApproveAll

Allows operator to transfer / send any token from the owner’s account. If expiration is set, then this allowance has a time/height limit

Fields

operator: String


RevokeAll

Remove previously granted ApproveAll permission

Fields

operator: String


Mint(MintMsg<T>)

Mint a new NFT, can only be called by the contract minter



Burn

Burn an NFT the sender has access to

Fields

token_id: String


UpdateCollectionInfo

Update specific collection info fields



UpdateStartTradingTime(Option<Timestamp>)

Called by the minter to update trading start time



FreezeCollectionInfo

Freeze collection info from further updates